//
//  Created by Pointr on 14/05/2020.
//  Copyright © 2020 Pointr. All rights reserved.
//

#import <PointrKit/PTRFeature.h>

#import <CoreLocation/CoreLocation.h>

NS_ASSUME_NONNULL_BEGIN

/// Enum for geofence type
typedef NS_ENUM(int, PTRGeofenceType) {
    /// Level geofence
    PTRGeofenceTypeLevel = 0,
    /// Global geofence.
    PTRGeofenceTypeGlobal = 1
};

/**
 * Geofence class.
 */
OBJC_EXPORT @interface PTRGeofence : PTRFeature

/**
 * The title of the geofence
 */
@property (strong, nonatomic, readonly) NSString *title;

/**
 * The coordinate of the enclosing circle's center
 */
@property (assign, nonatomic, readonly) CLLocationCoordinate2D coordinate;

/**
 * The radius of the enclosing circle
 */
@property (assign, nonatomic, readonly) double radius;

/**
 * Returns YES if given coordinate is inside this geofence
 * NO otherwise
 */
- (BOOL)containsCoordinate:(CLLocationCoordinate2D)coordinate;

/**
 * The type of geofence
 */
@property (nonatomic, assign, readonly) PTRGeofenceType type;

- (instancetype)init NS_UNAVAILABLE;

@end

NS_ASSUME_NONNULL_END
