//
//  PTRGeofenceManagerInterface.h
//  Pointr
//
//  Created by Pointr Labs on 21/03/16.
//  Copyright © 2016 Pointr. All rights reserved.
//

#import <PointrKit/PTRBuilding.h>
#import <PointrKit/PTRListenerHelper.h>
#import <PointrKit/PTRSite.h>

NS_ASSUME_NONNULL_BEGIN

@class PTRGeofenceEvent;
@class PTRGeofence;
@class PTRPoi;
/**
 *  PTRGeofenceManager is responsible for users region enters and exits.
 */
OBJC_EXPORT @protocol PTRGeofenceManagerDelegate<NSObject>

@optional

/**
 *  Notifies listeners when a geofence event is triggered.
 *
 *  @param event The event that is triggered.
 */
- (void)onGeofenceManagerGeofenceEvent:(nonnull PTRGeofenceEvent *)event;

@end

/**
 *  Main manager class responsible for location related triggers (enter, exit)
 */
OBJC_EXPORT @protocol PTRGeofenceManagerInterface<NSObject>

PTR_GENERATE_LISTENER_DECLARATIONS(PTRGeofenceManagerDelegate)

/////////////////////////////////////////////////////////////////////////
#pragma mark - Public properties
/////////////////////////////////////////////////////////////////////////

/**
 * Get list of geofences that are in "inside" state
 * @return list of geofences that the user is "inside"
 */
- (nonnull NSArray<PTRGeofence *> *)getInsideGeofences;

/**
 * Get list of all global geofences defined on Pointr Cloud
 * @return list of global geofences that are defined on Pointr Cloud
 */
- (nonnull NSArray<PTRGeofence *> *)getGlobalGeofences;

/**
 * Get the level geofences of the given site
 * @param siteId the id of the site to get the level geofences of
 * @return a list of the level geofences of the site
 */
- (nonnull NSArray<PTRGeofence *> *)getLevelGeofences:(int)siteId;

@end

NS_ASSUME_NONNULL_END
