//
//  PTRGraphNode.h
//  Pointr
//
//  Created by Pointr on 27/08/20.
//  Copyright © 2020 Pointr. All rights reserved.
//

#import <PointrKit/PTRFeature.h>

NS_ASSUME_NONNULL_BEGIN

/**
 * Types of nodes used for pathfinding and turn by turn directions.
 */
typedef NS_ENUM(int, PTRNodeType) {
    /// Not initialised
    PTRNodeTypeUnknown = -1,
    /// Regular walking node
    PTRNodeTypeRegular = 0,
    /// Fake node to indicate rotation (eg. "rotate left")
    PTRNodeTypeRotation = 1,
    /// Regular walking node, with a turn (eg. "turn left")
    PTRNodeTypeTurn = 2,
    /// Lift
    PTRNodeTypeLift = 3,
    /// Escalator
    PTRNodeTypeEscalator = 4,
    /// Walking band / slide
    PTRNodeTypeTravelator = 5,
    /// Stairs with an angle (different x,y on different floors)
    PTRNodeTypeAngularStairs = 6,
    /// Staircase (same x,y on each floor)
    PTRNodeTypeRotationalStairs = 7,
    /// Lift for service / internal use
    PTRNodeTypeServiceLift = 8,
    /// Skewed lift
    PTRNodeTypeSkewedLift = 9,
    /// Security checkpoint (eg. at the airport entrance)
    PTRNodeTypeSecurityControl = 10,
    /// Border control checkpoint (eg. at the immigration border)
    PTRNodeTypeBorderControl = 11,
    /// Ramp
    PTRNodeTypeRamp = 12,
    /// Small steps on a floor
    PTRNodeTypeSteps = 13,
    /// Stairs for service
    PTRNodeTypeServiceStairs = 14,
    /// Train
    PTRNodeTypeTrain = 15,
    /// Shuttle
    PTRNodeTypeShuttle = 16,
    /// Metro
    PTRNodeTypeMetro = 17,
    /// Bridge
    PTRNodeTypeBridge = 18
};

/**
 *  Class for all nodes, used in pathfinding.
 */
OBJC_EXPORT @interface PTRGraphNode : PTRFeature

/**
 *  Type of this node
 *  @see `PTRNodeType` enumeration
 */
@property (nonatomic, assign, readonly) PTRNodeType type;

/**
 *  User friendly string.
 */
@property (nonatomic, readonly) NSString *userFriendlyPortalString;

- (instancetype)init NS_UNAVAILABLE;

/**
 *  Checks if node has a portal type such as lifts or stairs or shuttle
 *  @return YES if node is of portal type, NO otherwise
 */
- (BOOL)isPortalType;

@end

NS_ASSUME_NONNULL_END
