//
//  PTRLogger.hpp
//  Pointr
//
//  Created by Ismail Ege AKPINAR on 11/11/2017.
//

#import <Foundation/Foundation.h>

//#define PTRAssert(e, m) [[PTRLogManager sharedInstance] assert:e function:__PRETTY_FUNCTION__ line:__LINE__ message:m]
#define PTRAssert(e, m)       \
    {                         \
        if (!(e))             \
            loge(@"%@", (m)); \
    }
#define PTRDirectAssert(m) loge(@"%@", (m));

#define logv(s, ...) \
    [PTRLogger logWithLevel:PTRLogLevelVerbose function:__PRETTY_FUNCTION__ line:__LINE__ format:s, ##__VA_ARGS__]
#define logd(s, ...) \
    [PTRLogger logWithLevel:PTRLogLevelDebug function:__PRETTY_FUNCTION__ line:__LINE__ format:s, ##__VA_ARGS__]
#define logi(s, ...) \
    [PTRLogger logWithLevel:PTRLogLevelInfo function:__PRETTY_FUNCTION__ line:__LINE__ format:s, ##__VA_ARGS__]
#define logw(s, ...) \
    [PTRLogger logWithLevel:PTRLogLevelWarning function:__PRETTY_FUNCTION__ line:__LINE__ format:s, ##__VA_ARGS__]
#define loge(s, ...) \
    [PTRLogger logWithLevel:PTRLogLevelError function:__PRETTY_FUNCTION__ line:__LINE__ format:s, ##__VA_ARGS__]

/// Log level.
typedef NS_ENUM(int, PTRLogLevel) {
    /// Verbose
    PTRLogLevelVerbose = 0,
    /// Debug.
    PTRLogLevelDebug = 1,
    /// Info.
    PTRLogLevelInfo = 2,
    /// Warning.
    PTRLogLevelWarning = 3,
    /// Error.
    PTRLogLevelError = 4
};

/// Logger level.
/// @note Logger level cannot be Debug. Debug's are always printed.
typedef NS_ENUM(int, PTRLoggerLevel) {
    /// All (equivalent to Verbose).
    PTRLoggerLevelAll = -999,
    /// Verbose.
    PTRLoggerLevelVerbose = 0,
    /// Info
    PTRLoggerLevelInfo = 2,
    /// Warning.
    PTRLoggerLevelWarning = 3,
    /// Error
    PTRLoggerLevelError = 4,
    /// Off
    PTRLoggerLevelOff = 999
};

/// Logger interface.
OBJC_EXPORT @interface PTRLogger : NSObject

/// Current logger level.
+ (PTRLoggerLevel)loggerLevel;

/**
 *  Determine minimum level of logs to be printed
 *  @param loggerLevel Logger level to be set.
 *  @warning Default level is PTRLoggerLevelAll
 */
+ (void)setLoggerLevel:(PTRLoggerLevel)loggerLevel;

/// Main logging method
/// @param logLevel Log level.
/// @param function Function.
/// @param line Line.
/// @param format Format.
/// @note This method passes log to cpp
+ (void)logWithLevel:(PTRLogLevel)logLevel
            function:(const char *)function
                line:(NSUInteger)line
              format:(NSString *)format, ... NS_FORMAT_FUNCTION(4, 5);

#pragma mark - Helper methods

/// Method to get string from log level.
/// @param level Log level.
+ (NSString *)stringFromLogLevel:(PTRLogLevel)level;

/// Method to get string from logger level.
/// @param level Logger level.
+ (NSString *)stringFromLoggerLevel:(PTRLoggerLevel)level;

@end
