//
//  PTRObstacle.h
//  PointrKit
//
//  Created by Pointr on 11/04/2022.
//

#import <PointrKit/PTRFeature.h>

NS_ASSUME_NONNULL_BEGIN

/**
 *  Different types of obstacles represented on the map.
 */
typedef NS_ENUM(int, PTRObstacleType) {
    /**
     *  Unknown type
     */
    PTRObstacleTypeUnknown,
    /**
     *  Actual physical wall
     */
    PTRObstacleTypeWall,
    /**
     *  Used for navigation only, virtual wall
     */
    PTRObstacleTypeTransparentWall
};

/**
 *  Object representing actual obstacle within the system.
 */
OBJC_EXPORT @interface PTRObstacle : PTRFeature

/**
 *  The index of the level on which the obstacle is located.
 */
@property (nonatomic, readonly) int levelIndex;

/**
 * Id of obstacle's site
 */
@property (nonatomic, readonly) int siteId;

/**
 * Id of obstacle's building
 */
@property (nonatomic, readonly) int buildingId;

/**
 *  Type of the obstacle represented as Enumeration
 */
@property (nonatomic, readonly) PTRObstacleType type;

/////////////////////////////////////////////////////////////////////////
#pragma mark - Init methods
/////////////////////////////////////////////////////////////////////////

- (instancetype)init NS_UNAVAILABLE;

/////////////////////////////////////////////////////////////////////////
#pragma mark - Helper methods
/////////////////////////////////////////////////////////////////////////

/**
 *  Converts given string to a known PTRObstacleType.
 *
 *  @param string String representation of a Obstacle Type Enumeration.
 *
 *  @return Enum value of the string.
 */
+ (PTRObstacleType)typeFromString:(NSString *)string;

/**
 *  Converts given PTRObstacleType to string.
 *
 *  @param type Obstacle Type.
 *
 *  @return The representative string.
 */
+ (NSString *)stringFromType:(PTRObstacleType)type;

@end

NS_ASSUME_NONNULL_END
