//
//  PTRPoiContainer.h
//  Pointr
//
//  Created by Pointr Labs on 29/08/16.
//  Copyright © 2016 Pointr. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <PointrKit/PTRPoiGroup.h>
#import <PointrKit/PTRSortedDictionary.h>

NS_ASSUME_NONNULL_BEGIN

@class PTRPoi;

/**
 * Contains poi results of poi management search query
 */
OBJC_EXPORT @interface PTRPoiContainer : NSObject

/**
 Initialiser with a poi

 @param poi PTRPoi object put in container
 @return PTRContainer which has only one poi
 */
- (instancetype)initWithPoi:(nonnull PTRPoi *)poi;

/**
 Initialiser with a poiGroup

 @param poiGroup PTRPoiGroup object including pois
 @return PTRContainer which has only pois with initial poiGrops pois
 */
- (instancetype)initWithPoiGroup:(nonnull PTRPoiGroup *)poiGroup;

/**
 Initializes new Container with array of groups puts objects in order that the array gave

 @param groups NSArray<PTRGroup> object
 @return PTRContainer created from groups
 */
- (instancetype)initWithGroups:(nonnull NSArray<PTRPoiGroup *> *)groups NS_DESIGNATED_INITIALIZER;

- (instancetype)init NS_UNAVAILABLE;

/**
 Gets poi Array of all contained pois for container

 @return Array of PTRPoi
 */
- (NSArray<PTRPoi *> *)getPoiList;

/**
 Gets PTRPoiGroup Array of all contained pois for container

 @return Array of PTRPoi
 */
- (NSArray<PTRPoiGroup *> *)getPoiGroupList;

@end

NS_ASSUME_NONNULL_END
