//
//  PTRSiteManagerInterface.h
//  Pointr
//
//  Created by Pointr in 2022.
//
//

#import <PointrKit/PTRBuilding.h>
#import <PointrKit/PTRListenerHelper.h>
#import <PointrKit/PTRMappedBeacon.h>
#import <PointrKit/PTRSite.h>

/// Site manager delegate for `PTRSiteManagerInterface` callbacks.
OBJC_EXPORT @protocol PTRSiteManagerDelegate<NSObject>

/**
 *    Notifies listeners that site data has been changed
 */
- (void)onSiteManagerDataChanged;

@end

/**
 * Manager for accessing site related models.
 */
OBJC_EXPORT @protocol PTRSiteManagerInterface<NSObject>

PTR_GENERATE_LISTENER_DECLARATIONS(PTRSiteManagerDelegate)

/////////////////////////////////////////////////////////////////////////
#pragma mark - Site Getters
/////////////////////////////////////////////////////////////////////////

/**
 * Gets site from internal identifier
 *
 * @return PTRSite object
 */
- (nullable PTRSite *)siteWithInternalIdentifier:(int)siteInternalIdentifier;

/**
 * Gets site from external identifier
 *
 * @return PTRSite object
 */
- (nullable PTRSite *)siteWithExternalIdentifier:(nonnull NSString *)siteExternalIdentifier;

/////////////////////////////////////////////////////////////////////////
#pragma mark - Building Getters
/////////////////////////////////////////////////////////////////////////

/**
 * Gets building from internal identifier
 *
 * @return PTRBuilding object
 */
- (nullable PTRBuilding *)buildingWithInternalIdentifier:(int)buildingInternalIdentifier;

/**
 * Gets building from external identifier
 *
 * @return PTRBuilding object
 */
- (nullable PTRBuilding *)buildingWithExternalIdentifier:(nonnull NSString *)buildingExternalIdentifier;

/////////////////////////////////////////////////////////////////////////
#pragma mark - Generic Getters
/////////////////////////////////////////////////////////////////////////

/**
 * Gets all site list
 *
 * @return array of PTRSite objects
 */
- (nonnull NSArray<PTRSite *> *)sites;

/**
 * Method to retrieve the list of all beacons.
 */
- (nonnull NSArray<PTRMappedBeacon *> *)mappedBeacons;

/**
 * Method to retrieve the list of beacons of a site.
 * @param site The site from which you want to retrieve the beacons.
 */
- (nonnull NSArray<PTRMappedBeacon *> *)mappedBeaconsForSite:(nonnull PTRSite *)site;

/**
 * Method to retrieve the list of beacons of a building.
 * @param building The building from which you want to retrieve the beacons.
 */
- (nonnull NSArray<PTRMappedBeacon *> *)mappedBeaconsForBuilding:(nonnull PTRBuilding *)building;

/**
 * Method to retrieve the list of beacons of a level.
 * @param level The level from which you want to retrieve the beacons.
 */
- (nonnull NSArray<PTRMappedBeacon *> *)mappedBeaconsForLevel:(nonnull PTRLevel *)level;

@end
