//
//  PTRPositionManager.h
//  Pointr
//
//  Created by Pointr Labs on 11/03/16.
//  Copyright © 2016 Pointr. All rights reserved.
//

#import <Foundation/Foundation.h>

#import <PointrKit/PTRCalculatedLocation.h>
#import <PointrKit/PTRListenerHelper.h>
#import <PointrKit/PTRPositioningTypes.h>

NS_ASSUME_NONNULL_BEGIN

/**
 *  PositionManagerDelegate keeps track of position related changes and callbacks
 */
OBJC_EXPORT @protocol PTRPositionManagerDelegate<NSObject>

@optional
/**
 *  Notifies listeners when a new location is calculated.
 *
 *  @warning This callback will only be fired if a valid location can be calculated.
 *
 *  @param calculatedLocation New location of the user.
 */
- (void)onPositionManagerCalculatedLocation:(nonnull PTRCalculatedLocation *)calculatedLocation;

/**
 *  Notifies listeners on service state changes
 *
 *  @param state New state of the positioning service.
 */
- (void)onPositionManagerPositioningServiceStateChangedTo:(PTRPositioningServiceState)state;

/**
 *  Notifies listeners on level change
 *
 *  @param level New level.
 */
- (void)onPositionManagerDetectedPositionLevelChange:(nonnull PTRLevel *)level;

/**
 *  Notifies listeners on position is fading after specified threshold.
 */
- (void)onPositionManagerPositionIsFading;

/**
 *  Notifies listeners on position is lost after specified threshoild.
 */
- (void)onPositionManagerPositionIsLost;

@end

/**
 * Main interface for all positioning functionality
 */
OBJC_EXPORT @protocol PTRPositionManagerInterface<NSObject>

PTR_GENERATE_LISTENER_DECLARATIONS(PTRPositionManagerDelegate)

/////////////////////////////////////////////////////////////////////////
#pragma mark - Public properties
/////////////////////////////////////////////////////////////////////////

/**
 * Last calculated valid position of the user
 */
@property (nonatomic, readonly, nullable) PTRCalculatedLocation *lastValidCalculatedLocation;

/**
 * Current position of the user
 */
@property (nonatomic, readonly, nullable) PTRCalculatedLocation *currentCalculatedLocation;

/**
 * Current positioning service state
 */
@property (nonatomic, readonly) PTRPositioningServiceState serviceState;

@end

NS_ASSUME_NONNULL_END
