//
//  Pointr.h
//
//
//  Created by Pointr on 04/12/14.
//  Copyright (c) 2014 Pointr. All rights reserved.
//

#import <Foundation/Foundation.h>

#import <PointrKit/PTRAdvertiser.h>
#import <PointrKit/PointrState.h>

@class PTRParams;
@class PTRPermissionManager;
@class PTRFeatureTypeCoordinator;
@protocol PTRAppStateManagerInterface;
@protocol PTRConfigurationManagerInterface;
@protocol PTRDataManagerInterface;
@protocol PTRGeofenceManagerInterface;
@protocol PTRGraphManagerInterface;
@protocol PTRPathManagerInterface;
@protocol PTRPoiManagerInterface;
@protocol PTRPositionManagerInterface;
@protocol PTRARControllerInterface;
@protocol PTRPushManagerInterface;
@protocol PTRUserManagerInterface;
@protocol PTRSiteManagerInterface;
@protocol PTRObstacleManagerInterface;

/**
 * Main Pointr Class which provides access to start and stop apis, current state, as well as access to all the managers.
 */
OBJC_EXPORT @interface Pointr : PTRAdvertiser<id<PointrStateChangeListener>>

/**
 * Callback method when Pointr state changes.
 * @param state  The state (`PointrState`) Pointr has changed to.
 */
typedef void (^PointrOnStateChangedCallback)(PointrState state);

/**
 * Unavaiable constructor of Pointr class. Pointr.shared should be used.
 */
- (nonnull instancetype)init
    __attribute__((unavailable("Pointr cannot be initialised through constructor, use Pointr.shared instead")));

/////////////////////////////////////////////////////////////////////////
#pragma mark - Properties
/////////////////////////////////////////////////////////////////////////

/**
 * Shared instance of the Pointr Class.
 */
@property (class, nonatomic, strong, nonnull, readonly) Pointr *shared;

/**
 * Indicates library start state
 */
@property (atomic, assign, readonly) PointrState state;

/**
 * Version number for this library
 */
@property (nonatomic, strong, nonnull, readonly) NSString *version;

/////////////////////////////////////////////////////////////////////////
#pragma mark - Pointr Managers
/////////////////////////////////////////////////////////////////////////

/**
 * App state manager.
 */
@property (nonatomic, strong, nullable, readonly) id<PTRAppStateManagerInterface> appStateManager;

/**
 * Configuration manager.
 */
@property (nonatomic, strong, nullable, readonly) id<PTRConfigurationManagerInterface> configurationManager;

/**
 * Permission Manager.
 */
@property (nonatomic, strong, nullable, readonly) PTRPermissionManager *permissionManager;

/**
 * User manager.
 */
@property (nonatomic, strong, nullable, readonly) id<PTRUserManagerInterface> userManager;

/**
 * Data manager.
 */
@property (nonatomic, strong, nullable, readonly) id<PTRDataManagerInterface> dataManager;

/**
 * Graph manager.
 */
@property (nonatomic, strong, nullable, readonly) id<PTRGraphManagerInterface> graphManager;

/**
 * Path manager.
 */
@property (nonatomic, strong, nullable, readonly) id<PTRPathManagerInterface> pathManager;

/**
 * Poi manager.
 */
@property (nonatomic, strong, nullable, readonly) id<PTRPoiManagerInterface> poiManager;

/**
 * Geofence manager.
 */
@property (nonatomic, strong, nullable, readonly) id<PTRGeofenceManagerInterface> geofenceManager;

/**
 * Position manager.
 */
@property (nonatomic, strong, nullable, readonly) id<PTRPositionManagerInterface> positionManager;

/**
 * Obstacle manager.
 */
@property (nonatomic, strong, nullable, readonly) id<PTRObstacleManagerInterface> obstacleManager;

/**
 * Site manager.
 */
@property (nonatomic, strong, nullable, readonly) id<PTRSiteManagerInterface> siteManager;

/**
 * Feature type coordinator..
 */
@property (nonatomic, strong, nullable, readonly) PTRFeatureTypeCoordinator *featureTypeCoordinator;

#ifdef PTR_UI

/**
 * Ar controller.
 */
@property (nonatomic, strong, nullable, readonly) id<PTRARControllerInterface> arController API_AVAILABLE(ios(11.0));

#endif

/////////////////////////////////////////////////////////////////////////
#pragma mark - Methods
/////////////////////////////////////////////////////////////////////////

/**
 * Method to start the Pointr SDK with setting parameters.
 * You should call this method and wait for `PointrState` to be `running`, before trying
 * to access any data on the SDK.
 * @param params PTRParams to customize execution
 * @param onStateChanged `PointrOnStateChangedCallback` block triggered upon state changes.
 */
- (void)startWithParams:(nonnull PTRParams *)params onStateChanged:(nonnull PointrOnStateChangedCallback)onStateChanged;

/**
 *  Stops all position calculation and data management operations.
 */
- (void)stop;

@end
